import requests
from cacheout import Cache
import time

class Client:
    def __init__(self, username, api_key, is_production=False, cache_enabled=True):
        '''
        :param username: user name for flight aware api
        :param api_key: api key for flight aware api
        :param wanted_keys: list of wanted keys to retrieve from the flight aware response payload
        '''

        self.FXML_URL = "https://flightxml.flightaware.com/json/FlightXML3/"
        self.authentication_info = (username, api_key)
        self.is_production = is_production
        self.cache_enabled = cache_enabled

        self.stubbed_find_flights_with_airline_info_response = "{'FlightInfoStatusResult': {'next_offset': -1, 'flights': [{'ident': 'DAL127', 'faFlightID': 'DAL127-1560500400-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 28560, 'filed_airspeed_kts': 377, 'distance_filed': 3583, 'filed_departure_time': {'epoch': 1560673200, 'tz': 'CEST', 'dow': 'Sunday', 'time': '10:20AM', 'date': '06/16/2019', 'localtime': 1560680400}, 'estimated_departure_time': {'epoch': 1560673800, 'tz': 'CEST', 'dow': 'Sunday', 'time': '10:30AM', 'date': '06/16/2019', 'localtime': 1560681000}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 600, 'filed_arrival_time': {'epoch': 1560701760, 'tz': 'EDT', 'dow': 'Sunday', 'time': '12:16PM', 'date': '06/16/2019', 'localtime': 1560687360}, 'estimated_arrival_time': {'epoch': 1560702360, 'tz': 'EDT', 'dow': 'Sunday', 'time': '12:26PM', 'date': '06/16/2019', 'localtime': 1560687960}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 600, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1560414000-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N841MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 26280, 'route': 'ZMR UN976 ARDID ARMED 4400N/02000W 4600N/03000W 4700N/04000W NATJ DOVEY N20B SAILE PLYMM PARCH3', 'filed_altitude': 330, 'display_filed_altitude': '33,000 feet', 'filed_airspeed_kts': 471, 'distance_filed': 3583, 'filed_departure_time': {'epoch': 1560586800, 'tz': 'CEST', 'dow': 'Saturday', 'time': '10:20AM', 'date': '06/15/2019', 'localtime': 1560594000}, 'estimated_departure_time': {'epoch': 1560587400, 'tz': 'CEST', 'dow': 'Saturday', 'time': '10:30AM', 'date': '06/15/2019', 'localtime': 1560594600}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 600, 'filed_arrival_time': {'epoch': 1560613080, 'tz': 'EDT', 'dow': 'Saturday', 'time': '11:38AM', 'date': '06/15/2019', 'localtime': 1560598680}, 'estimated_arrival_time': {'epoch': 1560613719, 'tz': 'EDT', 'dow': 'Saturday', 'time': '11:48AM', 'date': '06/15/2019', 'localtime': 1560599319}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 639, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1560346518-airline-0473', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1560327600-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N843MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 26880, 'route': 'SUPRY N106B VITOL PLYMM PARCH3', 'filed_altitude': 280, 'display_filed_altitude': '28,000 feet', 'filed_airspeed_kts': 467, 'distance_filed': 3618, 'filed_departure_time': {'epoch': 1560500400, 'tz': 'CEST', 'dow': 'Friday', 'time': '10:20AM', 'date': '06/14/2019', 'localtime': 1560507600}, 'estimated_departure_time': {'epoch': 1560501236, 'tz': 'CEST', 'dow': 'Friday', 'time': '10:33AM', 'date': '06/14/2019', 'localtime': 1560508436}, 'actual_departure_time': {'epoch': 1560501236, 'tz': 'CEST', 'dow': 'Friday', 'time': '10:33AM', 'date': '06/14/2019', 'localtime': 1560508436}, 'departure_delay': -300, 'filed_arrival_time': {'epoch': 1560527280, 'tz': 'EDT', 'dow': 'Friday', 'time': '11:48AM', 'date': '06/14/2019', 'localtime': 1560512880}, 'estimated_arrival_time': {'epoch': 1560528420, 'tz': 'EDT', 'dow': 'Friday', 'time': '12:07PM', 'date': '06/14/2019', 'localtime': 1560514020}, 'actual_arrival_time': {'epoch': 1560528420, 'tz': 'EDT', 'dow': 'Friday', 'time': '12:07PM', 'date': '06/14/2019', 'localtime': 1560514020}, 'arrival_delay': -1320, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1560260106-airline-0038', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1560241200-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N838MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 26760, 'route': 'ELSIR N316A TUSKY PLYMM PARCH3', 'filed_altitude': 300, 'display_filed_altitude': '30,000 feet', 'filed_airspeed_kts': 473, 'distance_filed': 3641, 'filed_departure_time': {'epoch': 1560414000, 'tz': 'CEST', 'dow': 'Thursday', 'time': '10:20AM', 'date': '06/13/2019', 'localtime': 1560421200}, 'estimated_departure_time': {'epoch': 1560414841, 'tz': 'CEST', 'dow': 'Thursday', 'time': '10:34AM', 'date': '06/13/2019', 'localtime': 1560422041}, 'actual_departure_time': {'epoch': 1560414841, 'tz': 'CEST', 'dow': 'Thursday', 'time': '10:34AM', 'date': '06/13/2019', 'localtime': 1560422041}, 'departure_delay': -540, 'filed_arrival_time': {'epoch': 1560440760, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:46AM', 'date': '06/13/2019', 'localtime': 1560426360}, 'estimated_arrival_time': {'epoch': 1560442260, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:11PM', 'date': '06/13/2019', 'localtime': 1560427860}, 'actual_arrival_time': {'epoch': 1560442260, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:11PM', 'date': '06/13/2019', 'localtime': 1560427860}, 'arrival_delay': -600, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1560173691-airline-0344', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1560154800-schedule-0001', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N837MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 26640, 'route': 'ZMR UN976 ARDID ARMED 4400N/02000W 4600N/03000W 4700N/04000W NATJ DOVEY N20B SAILE PLYMM PARCH3', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 470, 'distance_filed': 3669, 'filed_departure_time': {'epoch': 1560327600, 'tz': 'CEST', 'dow': 'Wednesday', 'time': '10:20AM', 'date': '06/12/2019', 'localtime': 1560334800}, 'estimated_departure_time': {'epoch': 1560329188, 'tz': 'CEST', 'dow': 'Wednesday', 'time': '10:46AM', 'date': '06/12/2019', 'localtime': 1560336388}, 'actual_departure_time': {'epoch': 1560329188, 'tz': 'CEST', 'dow': 'Wednesday', 'time': '10:46AM', 'date': '06/12/2019', 'localtime': 1560336388}, 'departure_delay': -60, 'filed_arrival_time': {'epoch': 1560354240, 'tz': 'EDT', 'dow': 'Wednesday', 'time': '11:44AM', 'date': '06/12/2019', 'localtime': 1560339840}, 'estimated_arrival_time': {'epoch': 1560356160, 'tz': 'EDT', 'dow': 'Wednesday', 'time': '12:16PM', 'date': '06/12/2019', 'localtime': 1560341760}, 'actual_arrival_time': {'epoch': 1560356160, 'tz': 'EDT', 'dow': 'Wednesday', 'time': '12:16PM', 'date': '06/12/2019', 'localtime': 1560341760}, 'arrival_delay': -540, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1560087328-airline-0399', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1560068400-schedule-0001', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N830MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 27960, 'route': 'PLYMM PARCH3', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 478, 'distance_filed': 3597, 'filed_departure_time': {'epoch': 1560241200, 'tz': 'CEST', 'dow': 'Tuesday', 'time': '10:20AM', 'date': '06/11/2019', 'localtime': 1560248400}, 'estimated_departure_time': {'epoch': 1560242184, 'tz': 'CEST', 'dow': 'Tuesday', 'time': '10:36AM', 'date': '06/11/2019', 'localtime': 1560249384}, 'actual_departure_time': {'epoch': 1560242184, 'tz': 'CEST', 'dow': 'Tuesday', 'time': '10:36AM', 'date': '06/11/2019', 'localtime': 1560249384}, 'departure_delay': -180, 'filed_arrival_time': {'epoch': 1560269160, 'tz': 'EDT', 'dow': 'Tuesday', 'time': '12:06PM', 'date': '06/11/2019', 'localtime': 1560254760}, 'estimated_arrival_time': {'epoch': 1560269783, 'tz': 'EDT', 'dow': 'Tuesday', 'time': '12:16PM', 'date': '06/11/2019', 'localtime': 1560255383}, 'actual_arrival_time': {'epoch': 1560269783, 'tz': 'EDT', 'dow': 'Tuesday', 'time': '12:16PM', 'date': '06/11/2019', 'localtime': 1560255383}, 'arrival_delay': -540, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1560000913-airline-0222', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1559982000-schedule-0001', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N832MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 26700, 'route': 'PLYMM PARCH3', 'filed_altitude': 300, 'display_filed_altitude': '30,000 feet', 'filed_airspeed_kts': 464, 'distance_filed': 3597, 'filed_departure_time': {'epoch': 1560154800, 'tz': 'CEST', 'dow': 'Monday', 'time': '10:20AM', 'date': '06/10/2019', 'localtime': 1560162000}, 'estimated_departure_time': {'epoch': 1560156746, 'tz': 'CEST', 'dow': 'Monday', 'time': '10:52AM', 'date': '06/10/2019', 'localtime': 1560163946}, 'actual_departure_time': {'epoch': 1560156746, 'tz': 'CEST', 'dow': 'Monday', 'time': '10:52AM', 'date': '06/10/2019', 'localtime': 1560163946}, 'departure_delay': 240, 'filed_arrival_time': {'epoch': 1560181500, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:45AM', 'date': '06/10/2019', 'localtime': 1560167100}, 'estimated_arrival_time': {'epoch': 1560183120, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:12PM', 'date': '06/10/2019', 'localtime': 1560168720}, 'actual_arrival_time': {'epoch': 1560183120, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:12PM', 'date': '06/10/2019', 'localtime': 1560168720}, 'arrival_delay': -960, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1559914500-airline-0338', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1559895600-schedule-0001', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N844MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 26520, 'route': 'NICSO N234A TUSKY PLYMM PARCH3', 'filed_altitude': 300, 'display_filed_altitude': '30,000 feet', 'filed_airspeed_kts': 468, 'distance_filed': 3607, 'filed_departure_time': {'epoch': 1560068400, 'tz': 'CEST', 'dow': 'Sunday', 'time': '10:20AM', 'date': '06/09/2019', 'localtime': 1560075600}, 'estimated_departure_time': {'epoch': 1560069387, 'tz': 'CEST', 'dow': 'Sunday', 'time': '10:36AM', 'date': '06/09/2019', 'localtime': 1560076587}, 'actual_departure_time': {'epoch': 1560069387, 'tz': 'CEST', 'dow': 'Sunday', 'time': '10:36AM', 'date': '06/09/2019', 'localtime': 1560076587}, 'departure_delay': -600, 'filed_arrival_time': {'epoch': 1560094920, 'tz': 'EDT', 'dow': 'Sunday', 'time': '11:42AM', 'date': '06/09/2019', 'localtime': 1560080520}, 'estimated_arrival_time': {'epoch': 1560095705, 'tz': 'EDT', 'dow': 'Sunday', 'time': '11:55AM', 'date': '06/09/2019', 'localtime': 1560081305}, 'actual_arrival_time': {'epoch': 1560095705, 'tz': 'EDT', 'dow': 'Sunday', 'time': '11:55AM', 'date': '06/09/2019', 'localtime': 1560081305}, 'arrival_delay': -1980, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1559828094-airline-0343', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1559809200-schedule-0003', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N840MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 27420, 'route': 'ZMR UN733 DESAT STG KOPAS 4400N/01500W 4400N/02000W 4400N/03000W 4400N/04000W 4400N/05000W RAFIN N88A TUSKY PLYMM PARCH3', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 470, 'distance_filed': 3669, 'filed_departure_time': {'epoch': 1559982000, 'tz': 'CEST', 'dow': 'Saturday', 'time': '10:20AM', 'date': '06/08/2019', 'localtime': 1559989200}, 'estimated_departure_time': {'epoch': 1559985351, 'tz': 'CEST', 'dow': 'Saturday', 'time': '11:15AM', 'date': '06/08/2019', 'localtime': 1559992551}, 'actual_departure_time': {'epoch': 1559985351, 'tz': 'CEST', 'dow': 'Saturday', 'time': '11:15AM', 'date': '06/08/2019', 'localtime': 1559992551}, 'departure_delay': 1251, 'filed_arrival_time': {'epoch': 1560009420, 'tz': 'EDT', 'dow': 'Saturday', 'time': '11:57AM', 'date': '06/08/2019', 'localtime': 1559995020}, 'estimated_arrival_time': {'epoch': 1560013020, 'tz': 'EDT', 'dow': 'Saturday', 'time': '12:57PM', 'date': '06/08/2019', 'localtime': 1559998620}, 'actual_arrival_time': {'epoch': 1560013020, 'tz': 'EDT', 'dow': 'Saturday', 'time': '12:57PM', 'date': '06/08/2019', 'localtime': 1559998620}, 'arrival_delay': 840, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1559741677-airline-0041', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1559722800-schedule-0001', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N835MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 27600, 'route': 'ZMR UN976 ARDID ARMED 4300N/02000W 4300N/03000W 4300N/04000W 4300N/05000W JEBBY CARAC N26B VITOL PLYMM PARCH3', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 481, 'distance_filed': 3649, 'filed_departure_time': {'epoch': 1559895600, 'tz': 'CEST', 'dow': 'Friday', 'time': '10:20AM', 'date': '06/07/2019', 'localtime': 1559902800}, 'estimated_departure_time': {'epoch': 1559896816, 'tz': 'CEST', 'dow': 'Friday', 'time': '10:40AM', 'date': '06/07/2019', 'localtime': 1559904016}, 'actual_departure_time': {'epoch': 1559896816, 'tz': 'CEST', 'dow': 'Friday', 'time': '10:40AM', 'date': '06/07/2019', 'localtime': 1559904016}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1559923200, 'tz': 'EDT', 'dow': 'Friday', 'time': '12:00PM', 'date': '06/07/2019', 'localtime': 1559908800}, 'estimated_arrival_time': {'epoch': 1559925254, 'tz': 'EDT', 'dow': 'Friday', 'time': '12:34PM', 'date': '06/07/2019', 'localtime': 1559910854}, 'actual_arrival_time': {'epoch': 1559925254, 'tz': 'EDT', 'dow': 'Friday', 'time': '12:34PM', 'date': '06/07/2019', 'localtime': 1559910854}, 'arrival_delay': 720, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1559649927-airline-0156', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1559636400-schedule-0001', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N842MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 27780, 'route': 'NANSO N80A WHALE PLYMM PARCH3', 'filed_altitude': 300, 'display_filed_altitude': '30,000 feet', 'filed_airspeed_kts': 479, 'distance_filed': 3605, 'filed_departure_time': {'epoch': 1559809200, 'tz': 'CEST', 'dow': 'Thursday', 'time': '10:20AM', 'date': '06/06/2019', 'localtime': 1559816400}, 'estimated_departure_time': {'epoch': 1559810016, 'tz': 'CEST', 'dow': 'Thursday', 'time': '10:33AM', 'date': '06/06/2019', 'localtime': 1559817216}, 'actual_departure_time': {'epoch': 1559810016, 'tz': 'CEST', 'dow': 'Thursday', 'time': '10:33AM', 'date': '06/06/2019', 'localtime': 1559817216}, 'departure_delay': 60, 'filed_arrival_time': {'epoch': 1559836980, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:03PM', 'date': '06/06/2019', 'localtime': 1559822580}, 'estimated_arrival_time': {'epoch': 1559838120, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:22PM', 'date': '06/06/2019', 'localtime': 1559823720}, 'actual_arrival_time': {'epoch': 1559838120, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:22PM', 'date': '06/06/2019', 'localtime': 1559823720}, 'arrival_delay': 1260, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1559539582-airline-0340', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1559539582-airline-0634', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N826MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 27180, 'route': 'PLYMM PARCH3', 'filed_altitude': 280, 'display_filed_altitude': '28,000 feet', 'filed_airspeed_kts': 474, 'distance_filed': 3597, 'filed_departure_time': {'epoch': 1559723400, 'tz': 'CEST', 'dow': 'Wednesday', 'time': '10:30AM', 'date': '06/05/2019', 'localtime': 1559730600}, 'estimated_departure_time': {'epoch': 1559723862, 'tz': 'CEST', 'dow': 'Wednesday', 'time': '10:37AM', 'date': '06/05/2019', 'localtime': 1559731062}, 'actual_departure_time': {'epoch': 1559723862, 'tz': 'CEST', 'dow': 'Wednesday', 'time': '10:37AM', 'date': '06/05/2019', 'localtime': 1559731062}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1559750580, 'tz': 'EDT', 'dow': 'Wednesday', 'time': '12:03PM', 'date': '06/05/2019', 'localtime': 1559736180}, 'estimated_arrival_time': {'epoch': 1559751840, 'tz': 'EDT', 'dow': 'Wednesday', 'time': '12:24PM', 'date': '06/05/2019', 'localtime': 1559737440}, 'actual_arrival_time': {'epoch': 1559751840, 'tz': 'EDT', 'dow': 'Wednesday', 'time': '12:24PM', 'date': '06/05/2019', 'localtime': 1559737440}, 'arrival_delay': -240, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1559453201-airline-0416', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1559453201-airline-0052', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N833MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 27420, 'route': 'ZMR UN976 ARDID ARMED 4300N/02000W 4300N/03000W 4300N/04000W 4300N/05000W JEBBY CARAC N28B WHALE PLYMM PARCH3', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 473, 'distance_filed': 3641, 'filed_departure_time': {'epoch': 1559637000, 'tz': 'CEST', 'dow': 'Tuesday', 'time': '10:30AM', 'date': '06/04/2019', 'localtime': 1559644200}, 'estimated_departure_time': {'epoch': 1559637196, 'tz': 'CEST', 'dow': 'Tuesday', 'time': '10:33AM', 'date': '06/04/2019', 'localtime': 1559644396}, 'actual_departure_time': {'epoch': 1559637196, 'tz': 'CEST', 'dow': 'Tuesday', 'time': '10:33AM', 'date': '06/04/2019', 'localtime': 1559644396}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1559664420, 'tz': 'EDT', 'dow': 'Tuesday', 'time': '12:07PM', 'date': '06/04/2019', 'localtime': 1559650020}, 'estimated_arrival_time': {'epoch': 1559664360, 'tz': 'EDT', 'dow': 'Tuesday', 'time': '12:06PM', 'date': '06/04/2019', 'localtime': 1559649960}, 'actual_arrival_time': {'epoch': 1559664360, 'tz': 'EDT', 'dow': 'Tuesday', 'time': '12:06PM', 'date': '06/04/2019', 'localtime': 1559649960}, 'arrival_delay': -1500, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1559366771-airline-0085', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1559366771-airline-0230', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N844MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 27120, 'route': 'ZMR UN976 ARDID ERPES 4000N/02000W 4000N/03000W 4000N/04000W 4000N/05000W 4100N/06000W DOVEY N20B SAILE PLYMM PARCH3', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 473, 'distance_filed': 3782, 'filed_departure_time': {'epoch': 1559550600, 'tz': 'CEST', 'dow': 'Monday', 'time': '10:30AM', 'date': '06/03/2019', 'localtime': 1559557800}, 'estimated_departure_time': {'epoch': 1559551634, 'tz': 'CEST', 'dow': 'Monday', 'time': '10:47AM', 'date': '06/03/2019', 'localtime': 1559558834}, 'actual_departure_time': {'epoch': 1559551634, 'tz': 'CEST', 'dow': 'Monday', 'time': '10:47AM', 'date': '06/03/2019', 'localtime': 1559558834}, 'departure_delay': -120, 'filed_arrival_time': {'epoch': 1559577720, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:02PM', 'date': '06/03/2019', 'localtime': 1559563320}, 'estimated_arrival_time': {'epoch': 1559578452, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:14PM', 'date': '06/03/2019', 'localtime': 1559564052}, 'actual_arrival_time': {'epoch': 1559578452, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:14PM', 'date': '06/03/2019', 'localtime': 1559564052}, 'arrival_delay': -780, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'adhoc': False}]}}"
        self.stubbed_find_flights_using_origin_destination_response = {'FindFlightResult': {'num_flights': 15, 'flights': [{'num_segments': 1, 'segments': [{'ident': 'DAL2456', 'faFlightID': 'DAL2456-1560346519-airline-0332', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2456', 'tailnumber': 'N359DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10320, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560526800, 'tz': 'EDT', 'dow': 'Friday', 'time': '11:40AM', 'date': '06/14/2019', 'localtime': 1560512400}, 'estimated_departure_time': {'epoch': 1560527520, 'tz': 'EDT', 'dow': 'Friday', 'time': '11:52AM', 'date': '06/14/2019', 'localtime': 1560513120}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 720, 'filed_arrival_time': {'epoch': 1560537120, 'tz': 'EDT', 'dow': 'Friday', 'time': '02:32PM', 'date': '06/14/2019', 'localtime': 1560522720}, 'estimated_arrival_time': {'epoch': 1560537899, 'tz': 'EDT', 'dow': 'Friday', 'time': '02:44PM', 'date': '06/14/2019', 'localtime': 1560523499}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 779, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2732-1560338700-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU2901', 'faFlightID': 'JBU2901-1560348180-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '2901', 'tailnumber': 'N958JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9780, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 457, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560520980, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:03AM', 'date': '06/14/2019', 'localtime': 1560506580}, 'estimated_departure_time': {'epoch': 1560522420, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:27AM', 'date': '06/14/2019', 'localtime': 1560508020}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560530760, 'tz': 'EDT', 'dow': 'Friday', 'time': '12:46PM', 'date': '06/14/2019', 'localtime': 1560516360}, 'estimated_arrival_time': {'epoch': 1560532259, 'tz': 'EDT', 'dow': 'Friday', 'time': '01:10PM', 'date': '06/14/2019', 'localtime': 1560517859}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1502-1560333660-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL2324', 'faFlightID': 'DAL2324-1560341100-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2324', 'tailnumber': 'N349DX', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9720, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560513900, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:05AM', 'date': '06/14/2019', 'localtime': 1560499500}, 'estimated_departure_time': {'epoch': 1560514500, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:15AM', 'date': '06/14/2019', 'localtime': 1560500100}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 600, 'filed_arrival_time': {'epoch': 1560523620, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:47AM', 'date': '06/14/2019', 'localtime': 1560509220}, 'estimated_arrival_time': {'epoch': 1560524220, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:57AM', 'date': '06/14/2019', 'localtime': 1560509820}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 600, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2279-1560260106-airline-0483', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1701', 'faFlightID': 'JBU1701-1560340800-schedule-0003', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1701', 'tailnumber': 'N970JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9720, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 457, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560513600, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:00AM', 'date': '06/14/2019', 'localtime': 1560499200}, 'estimated_departure_time': {'epoch': 1560514800, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:20AM', 'date': '06/14/2019', 'localtime': 1560500400}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560523320, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:42AM', 'date': '06/14/2019', 'localtime': 1560508920}, 'estimated_arrival_time': {'epoch': 1560524550, 'tz': 'EDT', 'dow': 'Friday', 'time': '11:02AM', 'date': '06/14/2019', 'localtime': 1560510150}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU2504-1560320760-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU601', 'faFlightID': 'JBU601-1560331800-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '601', 'tailnumber': 'N965JT', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9540, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 457, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560504600, 'tz': 'EDT', 'dow': 'Friday', 'time': '05:30AM', 'date': '06/14/2019', 'localtime': 1560490200}, 'estimated_departure_time': {'epoch': 1560505200, 'tz': 'EDT', 'dow': 'Friday', 'time': '05:40AM', 'date': '06/14/2019', 'localtime': 1560490800}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560514140, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:09AM', 'date': '06/14/2019', 'localtime': 1560499740}, 'estimated_arrival_time': {'epoch': 1560514740, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:19AM', 'date': '06/14/2019', 'localtime': 1560500340}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU36-1560260103-airline-0369', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL667', 'faFlightID': 'DAL667-1560260106-airline-0188', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '667', 'tailnumber': 'N313DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10500, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560470100, 'tz': 'EDT', 'dow': 'Thursday', 'time': '07:55PM', 'date': '06/13/2019', 'localtime': 1560455700}, 'estimated_departure_time': {'epoch': 1560470100, 'tz': 'EDT', 'dow': 'Thursday', 'time': '07:55PM', 'date': '06/13/2019', 'localtime': 1560455700}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560480600, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:50PM', 'date': '06/13/2019', 'localtime': 1560466200}, 'estimated_arrival_time': {'epoch': 1560480600, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:50PM', 'date': '06/13/2019', 'localtime': 1560466200}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2456-1560260106-airline-0264', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1201', 'faFlightID': 'JBU1201-1560260107-airline-0090', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1201', 'tailnumber': 'N958JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9540, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 456, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560465600, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:40PM', 'date': '06/13/2019', 'localtime': 1560451200}, 'estimated_departure_time': {'epoch': 1560466320, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:52PM', 'date': '06/13/2019', 'localtime': 1560451920}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560475140, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:19PM', 'date': '06/13/2019', 'localtime': 1560460740}, 'estimated_arrival_time': {'epoch': 1560475866, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:31PM', 'date': '06/13/2019', 'localtime': 1560461466}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1528-1560260103-airline-0426', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1401', 'faFlightID': 'JBU1401-1560260107-airline-0256', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1401', 'tailnumber': 'N999JQ', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 12660, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 456, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560457800, 'tz': 'EDT', 'dow': 'Thursday', 'time': '04:30PM', 'date': '06/13/2019', 'localtime': 1560443400}, 'estimated_departure_time': {'epoch': 1560457200, 'tz': 'EDT', 'dow': 'Thursday', 'time': '04:20PM', 'date': '06/13/2019', 'localtime': 1560442800}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560470460, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:01PM', 'date': '06/13/2019', 'localtime': 1560456060}, 'estimated_arrival_time': {'epoch': 1560469860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '07:51PM', 'date': '06/13/2019', 'localtime': 1560455460}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1202-1560260107-airline-0182', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL1656', 'faFlightID': 'DAL1656-1560260106-airline-0608', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '1656', 'tailnumber': 'N304DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10920, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560452940, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:09PM', 'date': '06/13/2019', 'localtime': 1560438540}, 'estimated_departure_time': {'epoch': 1560452940, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:09PM', 'date': '06/13/2019', 'localtime': 1560438540}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560463860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:11PM', 'date': '06/13/2019', 'localtime': 1560449460}, 'estimated_arrival_time': {'epoch': 1560463860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:11PM', 'date': '06/13/2019', 'localtime': 1560449460}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2938-1560265200-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU201', 'faFlightID': 'JBU201-1560260103-airline-0056', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '201', 'tailnumber': 'N804JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10140, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 SPIKY AR21 CRANS FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 464, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560444360, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:46PM', 'date': '06/13/2019', 'localtime': 1560429960}, 'estimated_departure_time': {'epoch': 1560443760, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:36PM', 'date': '06/13/2019', 'localtime': 1560429360}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560454500, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:35PM', 'date': '06/13/2019', 'localtime': 1560440100}, 'estimated_arrival_time': {'epoch': 1560453900, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:25PM', 'date': '06/13/2019', 'localtime': 1560439500}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 780, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A320', 'full_aircrafttype': 'A320', 'inbound_faFlightID': 'JBU154-1560258360-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL2456', 'faFlightID': 'DAL2456-1560260106-airline-0115', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2456', 'tailnumber': 'N313DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10440, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 472, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560440400, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:40AM', 'date': '06/13/2019', 'localtime': 1560426000}, 'estimated_departure_time': {'epoch': 1560440100, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:35AM', 'date': '06/13/2019', 'localtime': 1560425700}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': -300, 'filed_arrival_time': {'epoch': 1560450840, 'tz': 'EDT', 'dow': 'Thursday', 'time': '02:34PM', 'date': '06/13/2019', 'localtime': 1560436440}, 'estimated_arrival_time': {'epoch': 1560450540, 'tz': 'EDT', 'dow': 'Thursday', 'time': '02:29PM', 'date': '06/13/2019', 'localtime': 1560436140}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 360, 'status': 'Taxiing / Left Gate', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2732-1560252300-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU2901', 'faFlightID': 'JBU2901-1560261780-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '2901', 'tailnumber': 'N954JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9720, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1190, 'filed_departure_time': {'epoch': 1560434580, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:03AM', 'date': '06/13/2019', 'localtime': 1560420180}, 'estimated_departure_time': {'epoch': 1560438495, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:08AM', 'date': '06/13/2019', 'localtime': 1560424095}, 'actual_departure_time': {'epoch': 1560438495, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:08AM', 'date': '06/13/2019', 'localtime': 1560424095}, 'departure_delay': 720, 'filed_arrival_time': {'epoch': 1560444300, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:45PM', 'date': '06/13/2019', 'localtime': 1560429900}, 'estimated_arrival_time': {'epoch': 1560448080, 'tz': 'EDT', 'dow': 'Thursday', 'time': '01:48PM', 'date': '06/13/2019', 'localtime': 1560433680}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 420, 'status': 'En Route / Delayed', 'progress_percent': 21, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1502-1560247260-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU627', 'faFlightID': 'JBU627-1560254460-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '627', 'tailnumber': 'N958JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 12900, 'route': 'RBV J230 COPES J75 DHP ZQA RENAH Y397 SEKAR', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 460, 'distance_filed': 2089, 'filed_departure_time': {'epoch': 1560427260, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:01AM', 'date': '06/13/2019', 'localtime': 1560412860}, 'estimated_departure_time': {'epoch': 1560433963, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:52AM', 'date': '06/13/2019', 'localtime': 1560419563}, 'actual_departure_time': {'epoch': 1560433963, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:52AM', 'date': '06/13/2019', 'localtime': 1560419563}, 'departure_delay': 6103, 'filed_arrival_time': {'epoch': 1560440160, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:36AM', 'date': '06/13/2019', 'localtime': 1560425760}, 'estimated_arrival_time': {'epoch': 1560444956, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:55PM', 'date': '06/13/2019', 'localtime': 1560430556}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 9360, 'status': 'En Route / Delayed', 'progress_percent': 60, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1760-1560173686-airline-0187', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1701', 'faFlightID': 'JBU1701-1560254400-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1701', 'tailnumber': 'N999JQ', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10020, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 452, 'distance_filed': 1190, 'filed_departure_time': {'epoch': 1560427200, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:00AM', 'date': '06/13/2019', 'localtime': 1560412800}, 'estimated_departure_time': {'epoch': 1560428118, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:15AM', 'date': '06/13/2019', 'localtime': 1560413718}, 'actual_departure_time': {'epoch': 1560428118, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:15AM', 'date': '06/13/2019', 'localtime': 1560413718}, 'departure_delay': -360, 'filed_arrival_time': {'epoch': 1560437220, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:47AM', 'date': '06/13/2019', 'localtime': 1560422820}, 'estimated_arrival_time': {'epoch': 1560437460, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:51AM', 'date': '06/13/2019', 'localtime': 1560423060}, 'actual_arrival_time': {'epoch': 1560437460, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:51AM', 'date': '06/13/2019', 'localtime': 1560423060}, 'arrival_delay': -1080, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU162-1560173686-airline-0243', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL2324', 'faFlightID': 'DAL2324-1560254700-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2324', 'tailnumber': 'N376DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9360, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 460, 'distance_filed': 1190, 'filed_departure_time': {'epoch': 1560427500, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:05AM', 'date': '06/13/2019', 'localtime': 1560413100}, 'estimated_departure_time': {'epoch': 1560429340, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:35AM', 'date': '06/13/2019', 'localtime': 1560414940}, 'actual_departure_time': {'epoch': 1560429340, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:35AM', 'date': '06/13/2019', 'localtime': 1560414940}, 'departure_delay': 1840, 'filed_arrival_time': {'epoch': 1560436860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:41AM', 'date': '06/13/2019', 'localtime': 1560422460}, 'estimated_arrival_time': {'epoch': 1560438720, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:12AM', 'date': '06/13/2019', 'localtime': 1560424320}, 'actual_arrival_time': {'epoch': 1560438720, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:12AM', 'date': '06/13/2019', 'localtime': 1560424320}, 'arrival_delay': 2040, 'status': 'Arrived / Delayed', 'progress_percent': 100, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2279-1560173691-airline-0611', 'adhoc': False}]}], 'next_offset': 15}}, {'num_flights': 15, 'flights': [{'num_segments': 1, 'segments': [{'ident': 'DAL2456', 'faFlightID': 'DAL2456-1560346519-airline-0332', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2456', 'tailnumber': 'N359DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10320, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560526800, 'tz': 'EDT', 'dow': 'Friday', 'time': '11:40AM', 'date': '06/14/2019', 'localtime': 1560512400}, 'estimated_departure_time': {'epoch': 1560527520, 'tz': 'EDT', 'dow': 'Friday', 'time': '11:52AM', 'date': '06/14/2019', 'localtime': 1560513120}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 720, 'filed_arrival_time': {'epoch': 1560537120, 'tz': 'EDT', 'dow': 'Friday', 'time': '02:32PM', 'date': '06/14/2019', 'localtime': 1560522720}, 'estimated_arrival_time': {'epoch': 1560537899, 'tz': 'EDT', 'dow': 'Friday', 'time': '02:44PM', 'date': '06/14/2019', 'localtime': 1560523499}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 779, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2732-1560338700-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU2901', 'faFlightID': 'JBU2901-1560348180-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '2901', 'tailnumber': 'N958JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9780, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 457, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560520980, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:03AM', 'date': '06/14/2019', 'localtime': 1560506580}, 'estimated_departure_time': {'epoch': 1560522420, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:27AM', 'date': '06/14/2019', 'localtime': 1560508020}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560530760, 'tz': 'EDT', 'dow': 'Friday', 'time': '12:46PM', 'date': '06/14/2019', 'localtime': 1560516360}, 'estimated_arrival_time': {'epoch': 1560532259, 'tz': 'EDT', 'dow': 'Friday', 'time': '01:10PM', 'date': '06/14/2019', 'localtime': 1560517859}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1502-1560333660-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL2324', 'faFlightID': 'DAL2324-1560341100-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2324', 'tailnumber': 'N349DX', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9720, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560513900, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:05AM', 'date': '06/14/2019', 'localtime': 1560499500}, 'estimated_departure_time': {'epoch': 1560514500, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:15AM', 'date': '06/14/2019', 'localtime': 1560500100}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 600, 'filed_arrival_time': {'epoch': 1560523620, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:47AM', 'date': '06/14/2019', 'localtime': 1560509220}, 'estimated_arrival_time': {'epoch': 1560524220, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:57AM', 'date': '06/14/2019', 'localtime': 1560509820}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 600, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2279-1560260106-airline-0483', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1701', 'faFlightID': 'JBU1701-1560340800-schedule-0003', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1701', 'tailnumber': 'N970JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9720, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 457, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560513600, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:00AM', 'date': '06/14/2019', 'localtime': 1560499200}, 'estimated_departure_time': {'epoch': 1560514800, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:20AM', 'date': '06/14/2019', 'localtime': 1560500400}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560523320, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:42AM', 'date': '06/14/2019', 'localtime': 1560508920}, 'estimated_arrival_time': {'epoch': 1560524550, 'tz': 'EDT', 'dow': 'Friday', 'time': '11:02AM', 'date': '06/14/2019', 'localtime': 1560510150}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU2504-1560320760-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU601', 'faFlightID': 'JBU601-1560331800-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '601', 'tailnumber': 'N965JT', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9540, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 457, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560504600, 'tz': 'EDT', 'dow': 'Friday', 'time': '05:30AM', 'date': '06/14/2019', 'localtime': 1560490200}, 'estimated_departure_time': {'epoch': 1560505200, 'tz': 'EDT', 'dow': 'Friday', 'time': '05:40AM', 'date': '06/14/2019', 'localtime': 1560490800}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560514140, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:09AM', 'date': '06/14/2019', 'localtime': 1560499740}, 'estimated_arrival_time': {'epoch': 1560514740, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:19AM', 'date': '06/14/2019', 'localtime': 1560500340}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU36-1560260103-airline-0369', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL667', 'faFlightID': 'DAL667-1560260106-airline-0188', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '667', 'tailnumber': 'N313DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10500, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560470100, 'tz': 'EDT', 'dow': 'Thursday', 'time': '07:55PM', 'date': '06/13/2019', 'localtime': 1560455700}, 'estimated_departure_time': {'epoch': 1560470100, 'tz': 'EDT', 'dow': 'Thursday', 'time': '07:55PM', 'date': '06/13/2019', 'localtime': 1560455700}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560480600, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:50PM', 'date': '06/13/2019', 'localtime': 1560466200}, 'estimated_arrival_time': {'epoch': 1560480600, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:50PM', 'date': '06/13/2019', 'localtime': 1560466200}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2456-1560260106-airline-0264', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1201', 'faFlightID': 'JBU1201-1560260107-airline-0090', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1201', 'tailnumber': 'N958JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9540, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 456, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560465600, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:40PM', 'date': '06/13/2019', 'localtime': 1560451200}, 'estimated_departure_time': {'epoch': 1560466320, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:52PM', 'date': '06/13/2019', 'localtime': 1560451920}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560475140, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:19PM', 'date': '06/13/2019', 'localtime': 1560460740}, 'estimated_arrival_time': {'epoch': 1560475866, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:31PM', 'date': '06/13/2019', 'localtime': 1560461466}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1528-1560260103-airline-0426', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1401', 'faFlightID': 'JBU1401-1560260107-airline-0256', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1401', 'tailnumber': 'N999JQ', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 12660, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 456, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560457800, 'tz': 'EDT', 'dow': 'Thursday', 'time': '04:30PM', 'date': '06/13/2019', 'localtime': 1560443400}, 'estimated_departure_time': {'epoch': 1560457200, 'tz': 'EDT', 'dow': 'Thursday', 'time': '04:20PM', 'date': '06/13/2019', 'localtime': 1560442800}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560470460, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:01PM', 'date': '06/13/2019', 'localtime': 1560456060}, 'estimated_arrival_time': {'epoch': 1560469860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '07:51PM', 'date': '06/13/2019', 'localtime': 1560455460}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1202-1560260107-airline-0182', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL1656', 'faFlightID': 'DAL1656-1560260106-airline-0608', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '1656', 'tailnumber': 'N304DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10920, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560452940, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:09PM', 'date': '06/13/2019', 'localtime': 1560438540}, 'estimated_departure_time': {'epoch': 1560452940, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:09PM', 'date': '06/13/2019', 'localtime': 1560438540}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560463860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:11PM', 'date': '06/13/2019', 'localtime': 1560449460}, 'estimated_arrival_time': {'epoch': 1560463860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:11PM', 'date': '06/13/2019', 'localtime': 1560449460}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2938-1560265200-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU201', 'faFlightID': 'JBU201-1560260103-airline-0056', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '201', 'tailnumber': 'N804JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10140, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 SPIKY AR21 CRANS FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 464, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560444360, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:46PM', 'date': '06/13/2019', 'localtime': 1560429960}, 'estimated_departure_time': {'epoch': 1560443760, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:36PM', 'date': '06/13/2019', 'localtime': 1560429360}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560454500, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:35PM', 'date': '06/13/2019', 'localtime': 1560440100}, 'estimated_arrival_time': {'epoch': 1560453900, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:25PM', 'date': '06/13/2019', 'localtime': 1560439500}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 780, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A320', 'full_aircrafttype': 'A320', 'inbound_faFlightID': 'JBU154-1560258360-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL2456', 'faFlightID': 'DAL2456-1560260106-airline-0115', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2456', 'tailnumber': 'N313DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10440, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 472, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560440400, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:40AM', 'date': '06/13/2019', 'localtime': 1560426000}, 'estimated_departure_time': {'epoch': 1560440100, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:35AM', 'date': '06/13/2019', 'localtime': 1560425700}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': -300, 'filed_arrival_time': {'epoch': 1560450840, 'tz': 'EDT', 'dow': 'Thursday', 'time': '02:34PM', 'date': '06/13/2019', 'localtime': 1560436440}, 'estimated_arrival_time': {'epoch': 1560450540, 'tz': 'EDT', 'dow': 'Thursday', 'time': '02:29PM', 'date': '06/13/2019', 'localtime': 1560436140}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 360, 'status': 'Taxiing / Left Gate', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2732-1560252300-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU2901', 'faFlightID': 'JBU2901-1560261780-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '2901', 'tailnumber': 'N954JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9720, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1190, 'filed_departure_time': {'epoch': 1560434580, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:03AM', 'date': '06/13/2019', 'localtime': 1560420180}, 'estimated_departure_time': {'epoch': 1560438495, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:08AM', 'date': '06/13/2019', 'localtime': 1560424095}, 'actual_departure_time': {'epoch': 1560438495, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:08AM', 'date': '06/13/2019', 'localtime': 1560424095}, 'departure_delay': 720, 'filed_arrival_time': {'epoch': 1560444300, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:45PM', 'date': '06/13/2019', 'localtime': 1560429900}, 'estimated_arrival_time': {'epoch': 1560448080, 'tz': 'EDT', 'dow': 'Thursday', 'time': '01:48PM', 'date': '06/13/2019', 'localtime': 1560433680}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 420, 'status': 'En Route / Delayed', 'progress_percent': 21, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1502-1560247260-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU627', 'faFlightID': 'JBU627-1560254460-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '627', 'tailnumber': 'N958JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 12900, 'route': 'RBV J230 COPES J75 DHP ZQA RENAH Y397 SEKAR', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 460, 'distance_filed': 2089, 'filed_departure_time': {'epoch': 1560427260, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:01AM', 'date': '06/13/2019', 'localtime': 1560412860}, 'estimated_departure_time': {'epoch': 1560433963, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:52AM', 'date': '06/13/2019', 'localtime': 1560419563}, 'actual_departure_time': {'epoch': 1560433963, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:52AM', 'date': '06/13/2019', 'localtime': 1560419563}, 'departure_delay': 6103, 'filed_arrival_time': {'epoch': 1560440160, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:36AM', 'date': '06/13/2019', 'localtime': 1560425760}, 'estimated_arrival_time': {'epoch': 1560444956, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:55PM', 'date': '06/13/2019', 'localtime': 1560430556}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 9360, 'status': 'En Route / Delayed', 'progress_percent': 60, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1760-1560173686-airline-0187', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1701', 'faFlightID': 'JBU1701-1560254400-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1701', 'tailnumber': 'N999JQ', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10020, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 452, 'distance_filed': 1190, 'filed_departure_time': {'epoch': 1560427200, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:00AM', 'date': '06/13/2019', 'localtime': 1560412800}, 'estimated_departure_time': {'epoch': 1560428118, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:15AM', 'date': '06/13/2019', 'localtime': 1560413718}, 'actual_departure_time': {'epoch': 1560428118, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:15AM', 'date': '06/13/2019', 'localtime': 1560413718}, 'departure_delay': -360, 'filed_arrival_time': {'epoch': 1560437220, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:47AM', 'date': '06/13/2019', 'localtime': 1560422820}, 'estimated_arrival_time': {'epoch': 1560437460, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:51AM', 'date': '06/13/2019', 'localtime': 1560423060}, 'actual_arrival_time': {'epoch': 1560437460, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:51AM', 'date': '06/13/2019', 'localtime': 1560423060}, 'arrival_delay': -1080, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU162-1560173686-airline-0243', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL2324', 'faFlightID': 'DAL2324-1560254700-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2324', 'tailnumber': 'N376DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9360, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 460, 'distance_filed': 1190, 'filed_departure_time': {'epoch': 1560427500, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:05AM', 'date': '06/13/2019', 'localtime': 1560413100}, 'estimated_departure_time': {'epoch': 1560429340, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:35AM', 'date': '06/13/2019', 'localtime': 1560414940}, 'actual_departure_time': {'epoch': 1560429340, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:35AM', 'date': '06/13/2019', 'localtime': 1560414940}, 'departure_delay': 1840, 'filed_arrival_time': {'epoch': 1560436860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:41AM', 'date': '06/13/2019', 'localtime': 1560422460}, 'estimated_arrival_time': {'epoch': 1560438720, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:12AM', 'date': '06/13/2019', 'localtime': 1560424320}, 'actual_arrival_time': {'epoch': 1560438720, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:12AM', 'date': '06/13/2019', 'localtime': 1560424320}, 'arrival_delay': 2040, 'status': 'Arrived / Delayed', 'progress_percent': 100, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2279-1560173691-airline-0611', 'adhoc': False}]}], 'next_offset': 15}
        self.stubbed_find_flight_cancellation_statistics_response = {'FlightCancellationStatisticsResult': {'total_cancellations_worldwide': 1117, 'total_cancellations_national': 245, 'total_delays_worldwide': 23022, 'next_offset': -1, 'type_matching': 'airline', 'matching': [{'ident': 'AAL', 'description': 'American Airlines', 'cancellations': 63, 'delays': 834, 'total': 3570}]}}
        self.stubbed_find_airline_info_response = {'AirlineInfoResult': {'name': 'American Airlines Inc.', 'shortname': 'American Airlines', 'callsign': 'American', 'location': '', 'country': 'United States', 'phone': '+1-800-433-7300', 'url': 'http://www.aa.com/', 'wiki_url': 'https://en.wikipedia.org/wiki/American_Airlines', 'airbourne': 465, 'flights_last_24_hours': 3347}}

        if (self.is_production and self.cache_enabled):
            self.flight_aware_cache = Cache(maxsize=200, ttl=300, timer=time.time, default=None)

    def __make_request(self, end_point, payload):
        key = str(payload)
        response = self.flight_aware_cache.get(key) if self.cache_enabled else None
        if (response == None):
            print("Cache Miss!")
            response = requests.get(self.FXML_URL + end_point, params=payload, auth=self.authentication_info)

            if self.cache_enabled:
                self.flight_aware_cache.add(key, response)
        else:
            print("Cache Hit!")

        if response.status_code == 200:
            decodedResponse = response.json()
            return decodedResponse
        else:
            print("Unable to retrieve flight aware data", response.text)
            return RuntimeError("Unable to retrieve flight aware data")

    def find_flight_cancellation_statistics(self, time_period, type_matching, ident_filter):
        '''
        :param time_period: (must be 'yesterday', 'today', 'tomorrow', 'plus2days', 'twoDaysAgo', 'minus2plus12hrs', 'next36hrs', 'week')
        :param type_matching: (must be 'airline', 'origin', or 'destination')
        :param ident_filter: this argument can be blank/unspecified to request that all results are returned. Otherwise,
            when type_matching is 'airline', this argument can be the specific airline you are interested in.
            When type_matching is 'origin' or 'destination', this argument can be the specific airport you are interested in.
        :return: CancellationSummaryStruct
        '''

        if (self.is_production):
            payload = {'time_period': time_period, 'type_matching': type_matching, 'ident_filter': ident_filter}
            return self.__make_request('FlightCancellationStatistics', payload)
        else:
            return self.stubbed_find_flight_cancellation_statistics_response

    def find_airline_info(self, airline_code):
        '''

        :param airline_code: the ICAO airline ID (e.g., COA, ASA, UAL, etc.)
        :return: AirlineInfoStruct
        '''

        if (self.is_production):
            payload = {'airline_code': airline_code}
            return self.__make_request('AirlineInfo', payload)
        else:
            return self.stubbed_find_airline_info_response

    def find_flights_with_airline_info(self, airline_info):
        '''
        :param airline_info: 'DAL127'
        :return: list of flights that match the flight #
        '''
        if (self.is_production):
            payload = {'ident': airline_info}
            response = self.__make_request('FlightInfoStatus', payload)
            return response
        else:
            return self.stubbed_find_flights_with_airline_info_response

    def find_flights_using_origin_destination(self, origin, destination, airline, is_none_stop):
        '''
        :param origin: Origin airport ID
        :param destination: Destination airport ID
        :param airline: Airline ICAO code
        :param is_none_stop: True or False
        :return: list of matching flights on that route
        '''

        type = 'nonstop' if is_none_stop else 'auto'

        if (self.is_production):
            itinerary = []
            payload = {'origin': origin, 'destination': destination, 'type': type, 'filter': airline}
            response = self.__make_request("FindFlight", payload)

            for flight in response['FindFlightResult']['flights']:
                if flight['segments'][0]['progress_percent'] < 100:
                    itinerary.append(flight)

            return itinerary
        else:
            return self.stubbed_find_flights_using_origin_destination_response



if __name__ == '__main__':
    wanted_keys = ['ident', 'faFlightID', 'airline', 'flightnumber', 'origin',
                   'destination', 'filed_departure_time', 'filed_arrival_time',
                   'status', 'progress_percent', 'aircrafttype']

    fa = Client('omerwinrauke', '2e41815aaa99ccdb8d417b50e720ab196488f5ce', True, False)
    respone = fa.find_flights_using_origin_destination("JFK", "LAX", "airline", False)
    # print(respone)
    for flight in respone:
        print(flight)
        print("####")
    # print(fa.find_flights_with_airline_info("DAL127"))
    # print(fa.find_airline_info('JBU'))

